==> gongeek-0.0.6.tgz: package/gong.js <==
#!/usr/bin/env node

//design
//use case
//1. gong header.view header.v

var shell = require('shelljs'),
  path = require('path'),
  fs = require('fs'),

  sCommand = process.argv[2],
  curPath = shell.pwd();


//[ '/usr/local/bin/node', '/usr/local/bin/gong', 'asdas.v' ]

//解析命令行参数
function main() {
  var v = sCommand.indexOf('.v') ? sCommand.indexOf('.v') : sCommand.indexOf('.view'),
    nv = sCommand.indexOf('.nv');

  if (v !== -1) {
    dealCreateView(sCommand.substring(0, v), 'view');
  } else if (nv !== -1) {
    dealCreateView(sCommand.substring(0, nv), 'viewn');
  } else {
    shell.echo('\033[31m wrong args \033[0m');
    return 0;
  }
}

//tmpl为新建的view采用的模板名称

function dealCreateView(viewName, tmpl) {

  if (fs.existsSync(curPath + '/' + viewName + '.js')) {
    shell.echo('\033[31m wrong ' + viewName + ' view areadly exist \033[0m');
    return 0;
  }

  fs.readFile(path.resolve(__dirname, 'tmpl/' + tmpl + '.js'), {encoding: 'utf-8'}, function (err, data) {
    var outPut,
      renderData = {
        'viewName': viewName,
        'viewPath': curPath.substring(curPath.indexOf('app'))
      };
    outPut = data.replace(/\{\{(\w+)\}\}/g, function (match, p1) {
      return renderData[p1];
    });
    fs.writeFile(curPath + '/' + viewName + '.js', outPut, {encoding: 'utf-8'}, function () {
      shell.echo('\033[32m successful get ' + viewName + '.js \033[0m');
    });
  });

  fs.readFile(path.resolve(__dirname, 'tmpl/' + tmpl + '.html'), {encoding: 'utf-8'}, function (err, data) {
    var outPut,
      renderData = {
        'viewName': viewName
      };

    outPut = data.replace(/\{\{(\w+)\}\}/g, function (match, p1) {
      return renderData[p1];
    });
    fs.writeFile(curPath + '/' + viewName + '.html', outPut, {encoding: 'utf-8'}, function () {
      shell.echo('\033[32m successful get ' + viewName + '.html \033[0m');
    });
  });
}

main();

==> gongeek-0.0.8.tgz: package/gong.js <==
#!/usr/bin/env node

//design
//use case
//1. gong header.view header.v

var shell = require('shelljs'),
  path = require('path'),
  fs = require('fs'),

  sCommand = process.argv[2],
  curPath = shell.pwd();


//[ '/usr/local/bin/node', '/usr/local/bin/gong', 'asdas.v' ]

//解析命令行参数
function main() {
  var v = sCommand.indexOf('.v') ? sCommand.indexOf('.v') : sCommand.indexOf('.view'),
    nv = sCommand.indexOf('.nv'),
    ;

  if (v !== -1) {
    dealCreateView(sCommand.substring(0, v), 'view');
  } else if (nv !== -1) {
    dealCreateView(sCommand.substring(0, nv), 'viewn');
  } else {
    shell.echo('\033[31m wrong args \033[0m');
    return 0;
  }
}

//tmpl为新建的view采用的模板名称

function dealCreateView(viewName, tmpl) {

  if (fs.existsSync(curPath + '/' + viewName + '.js')) {
    shell.echo('\033[31m wrong ' + viewName + ' view areadly exist \033[0m');
    return 0;
  }

  fs.readFile(path.resolve(__dirname, 'tmpl/' + tmpl + '.js'), {encoding: 'utf-8'}, function (err, data) {
    var outPut,
      renderData = {
        'viewName': viewName,
        'viewPath': curPath.substring(curPath.indexOf('app'))
      };
    outPut = data.replace(/\{\{(\w+)\}\}/g, function (match, p1) {
      return renderData[p1];
    });
    fs.writeFile(curPath + '/' + viewName + '.js', outPut, {encoding: 'utf-8'}, function () {
      shell.echo('\033[32m successful get ' + viewName + '.js \033[0m');
    });
  });

  fs.readFile(path.resolve(__dirname, 'tmpl/' + tmpl + '.html'), {encoding: 'utf-8'}, function (err, data) {
    var outPut,
      renderData = {
        'viewName': viewName
      };

    outPut = data.replace(/\{\{(\w+)\}\}/g, function (match, p1) {
      return renderData[p1];
    });
    fs.writeFile(curPath + '/' + viewName + '.html', outPut, {encoding: 'utf-8'}, function () {
      shell.echo('\033[32m successful get ' + viewName + '.html \033[0m');
    });
  });
}

main();
